==> fanfou-sdk-2.1.0.tgz: package/lib/streaming.js <==
/**
 * Created by mogita on 2/24/17.
 */
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var User = require('./user');
var Status = require('./status');

var Streaming = function () {
  function Streaming(streaming) {
    _classCallCheck(this, Streaming);

    this.event = streaming.event;

    // Splits an "event" string apart for better accessibility
    this.schema = this.getSchema();
    this.action = this.getAction();

    this.created_at = streaming.created_at;
    this.source = null;
    this.target = null;
    this.object = null;
    this.is_replied = false;
    this.replied_by = null;
    this.is_mentioned = false;
    this.mentioned_by = null;

    if (_typeof(streaming.source) === 'object' && streaming.source !== null) {
      this.source = new User(streaming.source);
    }

    if (_typeof(streaming.target) === 'object' && streaming.target !== null) {
      this.target = new User(streaming.target);
    }

    if (_typeof(streaming.object) === 'object' && streaming.object !== null) {
      this.object = new Status(streaming.object);
    }

    if (this.schema === 'message' && this.action === 'create') {
      var by = this.source.screen_name;
      if (by === undefined || by === '') {
        by = this.source.id;
      }

      if (this.target !== null) {
        this.is_replied = true;
        this.replied_by = by;
      } else {
        var ruid = this.object.repost_user_id;
        if (ruid !== undefined && ruid !== '' && ruid !== this.source.id) {
          this.is_mentioned = true;
          this.mentioned_by = by;
        }
      }
    }
  }

  _createClass(Streaming, [{
    key: 'getSchema',
    value: function getSchema() {
      // user, friends, fav, message
      return this.event.split('.')[0] || '';
    }
  }, {
    key: 'getAction',
    value: function getAction() {
      // create, delete, request, updateprofile
      return this.event.split('.')[1] || '';
    }
  }]);

  return Streaming;
}();

module.exports = Streaming;

==> fanfou-sdk-2.1.10.tgz: package/lib/streaming.js <==
/**
 * Created by mogita on 2/24/17.
 */
'use strict';

const User = require('./user');
const Status = require('./status');

class Streaming {
  constructor(streaming) {
    this.event = streaming.event;

    // Splits an "event" string apart for better accessibility
    this.schema = this.getSchema();
    this.action = this.getAction();

    this.created_at = streaming.created_at;
    this.source = null;
    this.target = null;
    this.object = null;
    this.is_replied = false;
    this.replied_by = null;
    this.is_mentioned = false;
    this.mentioned_by = null;

    if (typeof streaming.source === 'object' && streaming.source !== null) {
      this.source = new User(streaming.source);
    }

    if (typeof streaming.target === 'object' && streaming.target !== null) {
      this.target = new User(streaming.target);
    }

    if (typeof streaming.object === 'object' && streaming.object !== null) {
      this.object = new Status(streaming.object);
    }

    if (this.schema === 'message' && this.action === 'create') {
      let by = this.source.screen_name;
      if (by === undefined || by === '') {
        by = this.source.id;
      }

      if (this.target !== null) {
        this.is_replied = true;
        this.replied_by = by;
      } else {
        let ruid = this.object.repost_user_id;
        if (ruid !== undefined && ruid !== '' && ruid !== this.source.id) {
          this.is_mentioned = true;
          this.mentioned_by = by;
        }
      }
    }
  }

  getSchema() {
    // user, friends, fav, message
    return this.event.split('.')[0] || '';
  }

  getAction() {
    // create, delete, request, updateprofile
    return this.event.split('.')[1] || '';
  }
}

module.exports = Streaming;
